﻿from PyQt4.QtCore import *
from PyQt4.QtGui import *
from PyQt4.uic import loadUi
import sys, os
from fbx import *

class Node() :
	def __init__(self, name, parent) :
		self.name = name
		self.parent = parent
		self.children = None
		self.type = None
	def addChild(self, child) :
		if not self.children : self.children = list()
		self.children.append(child)

def getTypeName(fbxNode) :
	nodeAttr = fbxNode.GetNodeAttribute()
	e = nodeAttr.GetAttributeType()
	sType = "Unknown"
	if FbxNodeAttribute.eNull == e : sType = "Null"
	elif FbxNodeAttribute.eMarker == e : sType = "Marker"
	elif FbxNodeAttribute.eSkeleton == e : sType = "Skeleton"
	elif FbxNodeAttribute.eMesh == e : sType = "Mesh"
	elif FbxNodeAttribute.eNurbs == e : sType = "Nurbs"
	elif FbxNodeAttribute.ePatch == e : sType = "Patch"
	elif FbxNodeAttribute.eCamera == e : sType = "Camera"
	elif FbxNodeAttribute.eLight == e : sType = "Light"
	return sType

def getHierarchy(fbxNode, node) :
	num = fbxNode.GetChildCount()
	if 0 == num : return
	for i in range(num) :
		fbxChild = fbxNode.GetChild(i)
		nodeChild = Node(fbxChild.GetName(), node)
		nodeChild.type = getTypeName(fbxChild)
		node.addChild(nodeChild)
		getHierarchy(fbxChild, nodeChild)

def printHierarchy(node, padding) :
	print padding + node.name
	if not node.children : return
	for child in node.children : printHierarchy(child, padding+"  ")

def addTreeItem(item, node) :
	if not node.children : return
	for child in node.children :
		i = QTreeWidgetItem()
		i.setText(0, "%s (%s)"%(child.name, child.type))
		item.addChild(i)
		addTreeItem(i, child)

class FBXData() :
	def __init__(self, filename) :
		self.filename = filename
		self.root = None
		self.load()
	def load(self) :
		print "loading : %s"%self.filename
		manager = FbxManager.Create()
		ios = FbxIOSettings.Create(manager, IOSROOT)
		manager.SetIOSettings(ios)
		importer = FbxImporter.Create(manager, "")
		if not importer.Initialize(self.filename, -1, manager.GetIOSettings()) :
			print "Failed to load file."
			return
		scene = FbxScene.Create(manager, "MyScene")
		importer.Import(scene)
		importer.Destroy()
		
		fbxRoot = scene.GetRootNode()
		self.root = Node(fbxRoot.GetName(), None)
		getHierarchy(fbxRoot, self.root)
		
		manager.Destroy()
		print "Succeeded to load file."

class FBXTest(QMainWindow) :
	def __init__(self) :
		self.fbx = None
		QMainWindow.__init__(self)
		sPath = os.path.abspath(os.path.dirname(sys.argv[0])) + "\\FBXTest.ui"
		self.ui = loadUi(sPath, self)
		self.show()
	def openFBX(self) :
		filename = QFileDialog.getOpenFileName(
			self, 						# parent
			QString("Open FBX file"),	# caption
			QString(""),				# directory
			QString("FBX file (*.fbx)")	# filter
		)
		if not filename : return
		self.fbx = FBXData(filename)
		
		#printHierarchy(self.root, "")
		self.ui.treeWidget.clear()
		rootItem = QTreeWidgetItem()
		rootItem.setText(0, self.fbx.root.name)
		self.ui.treeWidget.addTopLevelItem(rootItem)
		addTreeItem(rootItem, self.fbx.root)

app = QApplication(sys.argv)
FBXTest()
sys.exit(app.exec_())
